MallocAllocator class final

Manages memory on the native heap.

Does not initialize newly allocated memory to zero. Use CallocAllocator for zero-initialized memory on allocation.

For POSIX-based systems, this uses malloc and free. On Windows, it uses CoTaskMemAlloc and CoTaskMemFree.

Implemented types
Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
nativeFree → Pointer<NativeFinalizerFunction>
Returns a pointer to a native free function.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate<T extends NativeType>(int byteCount, {int? alignment}) → Pointer<T>
Allocates byteCount bytes of of unitialized memory on the native heap.
override
call<T extends SizedNativeType>([int count = 1]) → Pointer<T>

Available on Allocator, provided by the AllocatorAlloc extension

Allocates sizeOf<T>() * count bytes of memory using allocate.
free(Pointer<NativeType> pointer) → void
Releases memory allocated on the native heap.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited