Atlas class

Properties

atlasPagePaints → List<Paint>
final
atlasPages → List<Image>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAsset(String atlasFileName, {AssetBundle? bundle}) → Future<Atlas>
fromFile(String atlasFileName) → Future<Atlas>
fromUrl(String atlasFileName) → Future<Atlas>