BoneData class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getColor() → Color
getIndex() → int
getLength() → double
getName() → String
getParent() → BoneData?
getRotation() → double
getScaleX() → double
getScaleY() → double
getShearX() → double
getShearY() → double
getTransformMode() → TransformMode
getX() → double
getY() → double
isSkinRequired() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setIsSkinRequired(bool isSkinRequired) → void
setLength(double length) → void
setRotation(double rotation) → void
setScaleX(double scaleX) → void
setScaleY(double scaleY) → void
setShearX(double shearX) → void
setShearY(double shearY) → void
setTransformMode(TransformMode mode) → void
setX(double x) → void
setY(double y) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited