Color class

Constructors

Color(double r, double g, double b, double a)

Properties

a ↔ double
getter/setter pair
b ↔ double
getter/setter pair
g ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
r ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited