IkConstraint class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBendDirection() → int
getBones() → List<Bone>
getCompress() → bool
getData() → IkConstraintData
getMix() → double
getOrder() → int
getSoftness() → double
getStretch() → bool
getTarget() → Bone
isActive() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBendDirection(int bendDirection) → void
setCompress(bool compress) → void
setIsActive(bool isActive) → void
setMix(double mix) → void
setSoftness(double softness) → void
setStretch(bool stretch) → void
setTarget(Bone target) → void
toString() → String
A string representation of this object.
inherited
update() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited