IkConstraintData class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBendDirection() → int
getBones() → List<BoneData>
getCompress() → bool
getMix() → double
getName() → String
inherited
getOrder() → int
inherited
getSoftness() → double
getStretch() → bool
getTarget() → BoneData
getUniform() → bool
isSkinRequired() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBendDirection(int bendDirection) → void
setCompress(bool compress) → void
setIsSkinRequired(bool isSkinRequired) → void
inherited
setMix(double mix) → void
setOrder(int order) → void
inherited
setSoftness(double softness) → void
setStretch(bool stretch) → void
setTarget(BoneData target) → void
setUniform(bool uniform) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited