MeshAttachment class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeWorldVertices(Slot slot) → List<double>
inherited
copy() → Attachment<Pointer<NativeType>>
inherited
dispose() → void
inherited
getBones() → Int32List
inherited
getColor() → Color
getEdges() → Uint16List
getHeight() → double
getHullLength() → int
getName() → String
inherited
getParentMesh() → MeshAttachment?
getPath() → String
getRegion() → TextureRegion?
getRegionUVs() → Float32List
getSequence() → Sequence?
getTimelineAttachment() → Attachment<Pointer<NativeType>>?
inherited
getTriangles() → Uint16List
getType() → AttachmentType
inherited
getUVs() → Float32List
getVertices() → Float32List
inherited
getWidth() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setHeight(double height) → void
setHullLength(int hullLength) → void
setParentMesh(MeshAttachment? parentMesh) → void
setTimelineAttachment(Attachment<Pointer<NativeType>>? attachment) → void
inherited
setWidth(double width) → void
toString() → String
A string representation of this object.
inherited
updateRegion() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited