PathAttachment class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeWorldVertices(Slot slot) → List<double>
inherited
copy() → Attachment<Pointer<NativeType>>
inherited
dispose() → void
inherited
getBones() → Int32List
inherited
getColor() → Color
getLengths() → Float32List
getName() → String
inherited
getTimelineAttachment() → Attachment<Pointer<NativeType>>?
inherited
getType() → AttachmentType
inherited
getVertices() → Float32List
inherited
isClosed() → bool
isConstantSpeed() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setIsClosed(bool isClosed) → void
setIsConstantSpeed(bool isClosed) → void
setTimelineAttachment(Attachment<Pointer<NativeType>>? attachment) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited