PathConstraint class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<Bone>
getMixRotate() → double
getMixX() → double
getMixY() → double
getOrder() → int
getPosition() → double
getSpacing() → double
getTarget() → Slot
isActive() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsActive(bool isActive) → void
setMixRotate(double mixRotate) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setPosition(double position) → void
setSpacing(double spacing) → void
setTarget(Slot target) → void
toString() → String
A string representation of this object.
inherited
update() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited