PathConstraintData class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<BoneData>
getMixRotate() → double
getMixX() → double
getMixY() → double
getName() → String
inherited
getOffsetRotation() → double
getOrder() → int
inherited
getPosition() → double
getPositionMode() → PositionMode
getRotateMode() → RotateMode
getSpacing() → double
getSpacingMode() → SpacingMode
getTarget() → SlotData
isSkinRequired() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsSkinRequired(bool isSkinRequired) → void
inherited
setMixRotate(double mixRotate) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setOffsetRotation(double offsetRotation) → void
setOrder(int order) → void
inherited
setPosition(double position) → void
setPositionMode(PositionMode positionMode) → void
setRotateMode(RotateMode rotateMode) → void
setSpacing(double spacing) → void
setSpacingMode(SpacingMode spacingMode) → void
setTarget(SlotData target) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited