PointAttachment class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeWorldPosition(Bone bone) → Vec2
computeWorldRotation(Bone bone) → double
copy() → Attachment<Pointer<NativeType>>
inherited
dispose() → void
inherited
getColor() → Color
getName() → String
inherited
getRotation() → double
getType() → AttachmentType
inherited
getX() → double
getY() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setRotation(double rotation) → void
setX(double x) → void
setY(double y) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited