RegionAttachment class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeWorldVertices(Slot slot) → List<double>
copy() → Attachment<Pointer<NativeType>>
inherited
dispose() → void
inherited
getColor() → Color
getHeight() → double
getName() → String
inherited
getOffset() → Float32List
getPath() → String
getRegion() → TextureRegion?
getRotation() → double
getScaleX() → double
getScaleY() → double
getSequence() → Sequence?
getType() → AttachmentType
inherited
getUVs() → Float32List
getWidth() → double
getX() → double
getY() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(double r, double g, double b, double a) → void
setHeight(double height) → void
setRotation(double rotation) → void
setScaleX(double scaleX) → void
setScaleY(double scaleY) → void
setWidth(double width) → void
setX(double x) → void
setY(double y) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited