SkeletonDrawable class

Constructors

SkeletonDrawable(Atlas atlas, SkeletonData skeletonData, bool _ownsAtlasAndSkeletonData)

Properties

animationState ↔ AnimationState
latefinal
animationStateData ↔ AnimationStateData
latefinal
atlas → Atlas
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skeleton ↔ Skeleton
latefinal
skeletonData → SkeletonData
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() → List<RenderCommand>
renderToCanvas(Canvas canvas) → void
renderToPictureRecorder(double width, double height) → PictureRecorder
renderToPng(double width, double height) → Future<Uint8List>
renderToRawImageData(double width, double height) → Future<RawImageData>
toString() → String
A string representation of this object.
inherited
update(double delta) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAsset(String atlasFile, String skeletonFile, {AssetBundle? bundle}) → Future<SkeletonDrawable>
fromFile(String atlasFile, String skeletonFile) → Future<SkeletonDrawable>
fromHttp(String atlasFile, String skeletonFile) → Future<SkeletonDrawable>