Skin class

Constructors

Skin(String name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSkin(Skin other) → void
copy(Skin other) → void
dispose() → void
getAttachment(int slotIndex, String name) → Attachment<Pointer<NativeType>>?
getBones() → List<BoneData>
getConstraints() → List<ConstraintData<Pointer<NativeType>>>
getEntries() → List<SkinEntry>
getName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAttachment(int slotIndex, String name) → void
setAttachment(int slotIndex, String name, Attachment<Pointer<NativeType>>? attachment) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited