Slot class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAttachment() → Attachment<Pointer<NativeType>>?
getBone() → Bone
getColor() → Color
getDarkColor() → Color
getData() → SlotData
getSequenceIndex() → int
getSkeleton() → Skeleton
hasDarkColor() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttachment(Attachment<Pointer<NativeType>>? attachment) → void
setColor(Color color) → void
setDarkColor(Color color) → void
setSequenceIndex(int sequenceIndex) → void
setToSetupPose() → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited