SlotData class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAttachmentName() → String
getBlendMode() → BlendMode
getBoneData() → BoneData
getColor() → Color
getDarkColor() → Color
getIndex() → int
getName() → String
hasDarkColor() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttachmentName(String attachmentName) → void
setBlendMode(BlendMode mode) → void
setColor(double r, double g, double b, double a) → void
setDarkColor(double r, double g, double b, double a) → void
setHasDarkColor(bool hasDarkColor) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited