TransformConstraint class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<Bone>
getData() → TransformConstraintData
getMixRotate() → double
getMixScaleX() → double
getMixScaleY() → double
getMixShearY() → double
getMixX() → double
getMixY() → double
getOrder() → int
getTarget() → Bone
isActive() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsActive(bool isActive) → void
setMixRotate(double mixRotate) → void
setMixScaleX(double mixScaleX) → void
setMixScaleY(double mixScaleY) → void
setMixShearY(double mixShearY) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setTarget(Bone target) → void
toString() → String
A string representation of this object.
inherited
update() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited