TransformConstraintData class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBones() → List<BoneData>
getMixRotate() → double
getMixScaleX() → double
getMixScaleY() → double
getMixShearY() → double
getMixX() → double
getMixY() → double
getName() → String
inherited
getOffsetRotation() → double
getOffsetScaleX() → double
getOffsetScaleY() → double
getOffsetShearY() → double
getOffsetX() → double
getOffsetY() → double
getOrder() → int
inherited
getTarget() → BoneData
isLocal() → bool
isRelative() → bool
isSkinRequired() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsLocal(bool isLocal) → void
setIsRelative(bool isRelative) → void
setIsSkinRequired(bool isSkinRequired) → void
inherited
setMixRotate(double mixRotate) → void
setMixScaleX(double mixScaleX) → void
setMixScaleY(double mixScaleY) → void
setMixShearY(double mixShearY) → void
setMixX(double mixX) → void
setMixY(double mixY) → void
setOffsetRotation(double offsetRotation) → void
setOffsetScaleX(double offsetScaleX) → void
setOffsetScaleY(double offsetScaleY) → void
setOffsetShearY(double offsetShearY) → void
setOffsetX(double offsetX) → void
setOffsetY(double offsetY) → void
setOrder(int order) → void
inherited
setTarget(BoneData target) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited