SkinAndAnimationBounds class

Inheritance

Constructors

SkinAndAnimationBounds({List<String>? skins, String? animation, double stepTime = 0.1})

Properties

animation → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skins → List<String>
final
stepTime → double
final

Methods

computeBounds(SkeletonDrawable drawable) → Bounds
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited